﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Runtime.InteropServices;   //必须添加，不然DllImport报错
using System.Threading;
namespace ao_waveform_sync
{
    class Program
    {
        static void Main(string[] args)
        {
            int temp;
	    int i;
	    int DevIndex = 0;
	    byte Chan = 0;
	    float[] waveform = new float[1000];

	    // 生成一个由 1000 个点组成的正弦波
	    for(i = 0; i < 1000; i++)
	    {
		    waveform[i] = waveform[i] = (float)(Math.Sin((i* 2 * Math.PI)/1000));
	    }

	    // 调用函数时，返回错误代码
	    // 打开设备
	    temp = USB5000DLL.USB5OpenDevice(DevIndex);

	    // 分别对 4 个通道进行设置
	    for(Chan = 0; Chan < 4; Chan++)
	    {
		    // 清除触发标志
		    temp =USB5000DLL.SetUSB5ClrAoTrigger(DevIndex, Chan);

		    // 清空 AoFifo
		    temp = USB5000DLL.SetUSB5ClrAoFifo(DevIndex, Chan);

		    // 设置为 NCycle 模式，代表硬件 Fifo 缓冲的有限次数/无限循环输出模式，其循环次数由 SetUSB5AoCycle() 函数决定。
		    temp = USB5000DLL.SetUSB5AoSampleMode(DevIndex, Chan, 1);

		    // 设置 Ao 采样周期为 10000ns，即 100kSa/s
		    temp = USB5000DLL.SetUSB5AoSampleRate(DevIndex, Chan, 10000);

		    // 设置触发源为 GlobalSoftTrig 全局软件触发
		    temp = USB5000DLL.SetUSB5AoTrigSource(DevIndex, Chan, 255);

		    //设置采样时钟源为 Ao 内部采样时钟源，该时采样时钟频率由 SetUSB5AoSampleRate() 函数设定。
		    temp = USB5000DLL.SetUSB5AoConvSource(DevIndex, Chan, 0);

		    // 设置无限循环输出，AoCycle 参数设置为 0 即可。
		    temp = USB5000DLL.SetUSB5AoCycle(DevIndex, Chan, 0);

		    // 将波形数组 waveform 的前 500 个点下载到 AoFifo 中，
		    temp = USB5000DLL.SetUSB5AoDataFifo(DevIndex, Chan, waveform, 1000);
	    }

	    // 选择需要通道的 ao 通道。
	    // 0xf 参数的 bit-0 到 bit 3 对应 ao 0 到 ao 3。
	    // 例如，如果只选择 ai 0 和 ai 1，此参数应设置为 0x03。
	    // 依次类推。
	    temp = USB5000DLL.SetUSB5AoSync(DevIndex, 0x0f);

	    // 启动全局软件触发
	    temp = USB5000DLL.SetUSB5GlobalSoftTrig(DevIndex);

        Thread.Sleep(100);
	
	    // 关闭设备
	    temp = USB5000DLL.USB5CloseDevice(DevIndex);

        /*如需了解更多函数参数意义，则需要访问smmacq.cn对应产品系列函数手册进行查询
         *以及了解各类函数返回值负数代表的错误意义            
         */
        }
    }
    class USB5000DLL
    {
        [DllImport("USB5000.dll")]
        public static extern int FindUSB5DAQ();
        [DllImport("USB5000.dll")]
        public static extern int USB5OpenDevice(int DevIndex);
        [DllImport("USB5000.dll")]
        public static extern int USB5CloseDevice(int DevIndex);
        [DllImport("USB5000.dll")]
        public static extern int USB5ReadDevcieSN(int DevIndex);
        [DllImport("USB5000.dll")]
        public static extern int USB5ReadDevcieModel(int DevIndex);

        //--------------------------------------------------------------------------
        // Ananlog Input Configuration

        [DllImport("USB5000.dll")]
        public static extern int SetUSB5AiSampleRate(int DevIndex, uint SamplePeriod);
        [DllImport("USB5000.dll")]
        public static extern int SetUSB5AiSampleMode(int DevIndex, byte AiSampleMode);
        [DllImport("USB5000.dll")]
        public static extern int SetUSB5AiRange(int DevIndex, byte Chan, float AiRange);
        [DllImport("USB5000.dll")]
        public static extern int SetUSB5AiChanSel(int DevIndex, byte Chan, byte Sel);
        [DllImport("USB5000.dll")]
        public static extern int SetUSB5AiTrigSource(int DevIndex, byte AiTrigSource);
        [DllImport("USB5000.dll")]
        public static extern int SetUSB5AiConvSource(int DevIndex, byte AiConvSource);
        [DllImport("USB5000.dll")]
        public static extern int SetUSB5AiPreTrigPoints(int DevIndex, uint AiPreTrigPoints);
        [DllImport("USB5000.dll")]
        public static extern int SetUSB5AiOneShotPoints(int DevIndex, uint AiOneShotPoints);
        [DllImport("USB5000.dll")]
        public static extern int SetUSB5ClrAiFifo(int DevIndex);

        //--------------------------------------------------------------------------
        // Digital I/O Configuration

        [DllImport("USB5000.dll")]
        public static extern int SetUSB5DiSampleRate(int DevIndex, uint SamplePeriod);
        [DllImport("USB5000.dll")]
        public static extern int SetUSB5DiSampleMode(int DevIndex, byte DiSampleMode);
        [DllImport("USB5000.dll")]
        public static extern int SetUSB5DiTrigSource(int DevIndex, byte DiTrigSource);
        [DllImport("USB5000.dll")]
        public static extern int SetUSB5DiConvSource(int DevIndex, byte DiConvSource);
        [DllImport("USB5000.dll")]
        public static extern int SetUSB5DiPreTrigPoints(int DevIndex, uint DiPreTrigPoints);
        [DllImport("USB5000.dll")]
        public static extern int SetUSB5DiOneShotPoints(int DevIndex, uint DiOneShotPoints);
        [DllImport("USB5000.dll")]
        public static extern int SetUSB5ClrDiFifo(int DevIndex);

        [DllImport("USB5000.dll")]
        public static extern int SetUSB5DoSampleRate(int DevIndex, uint SamplePeriod);
        [DllImport("USB5000.dll")]
        public static extern int SetUSB5DoSampleMode(int DevIndex, byte DoSampleMode);
        [DllImport("USB5000.dll")]
        public static extern int SetUSB5DoTrigSource(int DevIndex, byte DoTrigSource);
        [DllImport("USB5000.dll")]
        public static extern int SetUSB5DoConvSource(int DevIndex, byte DoConvSource);
        [DllImport("USB5000.dll")]
        public static extern int SetUSB5DoCycle(int DevIndex, uint DoCycle);
        [DllImport("USB5000.dll")]
        public static extern int SetUSB5DoDataFifo(int DevIndex, uint[] Value, uint Len);
        [DllImport("USB5000.dll")]
        public static extern int SetUSB5ClrDoFifo(int DevIndex);
        [DllImport("USB5000.dll")]
        public static extern int SetUSB5DoWaveCtrl(int DevIndex, uint Chan);
        [DllImport("USB5000.dll")]
        public static extern int SetUSB5DoImmediately(int DevIndex, uint Chan, uint Value);

        //--------------------------------------------------------------------------
        // Ananlog Output Configuration

        [DllImport("USB5000.dll")]
        public static extern int SetUSB5AoSampleRate(int DevIndex, byte Chan, uint SamplePeriod);
        [DllImport("USB5000.dll")]
        public static extern int SetUSB5AoSampleMode(int DevIndex, byte Chan, byte AoSampleMode);
        [DllImport("USB5000.dll")]
        public static extern int SetUSB5AoTrigSource(int DevIndex, byte Chan, byte AoTrigSource);
        [DllImport("USB5000.dll")]
        public static extern int SetUSB5AoConvSource(int DevIndex, byte Chan, byte AoConvSource);
        [DllImport("USB5000.dll")]
        public static extern int SetUSB5AoCycle(int DevIndex, byte Chan, byte AoCycle);
        [DllImport("USB5000.dll")]
        public static extern int SetUSB5AoDataFifo(int DevIndex, byte Chan, float[] Voltage, uint Len);
        [DllImport("USB5000.dll")]
        public static extern int SetUSB5ClrAoFifo(int DevIndex, byte Chan);
        [DllImport("USB5000.dll")]
        public static extern int SetUSB5AoSync(int DevIndex, byte Chans);
        [DllImport("USB5000.dll")]
        public static extern int SetUSB5AoImmediately(int DevIndex, byte Chan, float Voltage);

        //--------------------------------------------------------------------------
        // Trig Control

        [DllImport("USB5000.dll")]
        public static extern int SetUSB5AiSoftTrig(int DevIndex);
        [DllImport("USB5000.dll")]
        public static extern int SetUSB5DiSoftTrig(int DevIndex);
        [DllImport("USB5000.dll")]
        public static extern int SetUSB5DoSoftTrig(int DevIndex);
        [DllImport("USB5000.dll")]
        public static extern int SetUSB5AoSoftTrig(int DevIndex, byte Chan);
        [DllImport("USB5000.dll")]
        public static extern int SetUSB5GlobalSoftTrig(int DevIndex);

        [DllImport("USB5000.dll")]
        public static extern int SetUSB5ClrTrigger(int DevIndex);
        [DllImport("USB5000.dll")]
        public static extern int SetUSB5ClrAiTrigger(int DevIndex);
        [DllImport("USB5000.dll")]
        public static extern int SetUSB5ClrDiTrigger(int DevIndex);
        [DllImport("USB5000.dll")]
        public static extern int SetUSB5ClrDoTrigger(int DevIndex);
        [DllImport("USB5000.dll")]
        public static extern int SetUSB5ClrAoTrigger(int DevIndex, byte Chan);
        [DllImport("USB5000.dll")]
        public static extern int SetUSB5ClrGlobalSoftTrig(int DevIndex);

        //--------------------------------------------------------------------------
        // Sync Configuration

        [DllImport("USB5000.dll")]
        public static extern int SetUSB5ExtTrigOutSource(int DevIndex, byte Source);
        [DllImport("USB5000.dll")]
        public static extern int SetUSB5ExtConvOutSource(int DevIndex, byte Source);

        //--------------------------------------------------------------------------
        // Get Data Acquired

        [DllImport("USB5000.dll")]
        public static extern int USB5GetAi(int DevIndex, uint Points, float[] Ai, int TimeOut);
        [DllImport("USB5000.dll")]
        public static extern int USB5GetDi(int DevIndex, uint Points, byte[] Di, int TimeOut);
    }
}
